@@ -1,11 +1,21 @@
 trio.sim <-
-function(freq,  interaction="1R and 2D", prev=1e-3, OR=1, n=100, rep=1,  step.save=NULL, step.load=NULL,  verbose=FALSE){
+function(freq,  interaction="1R and 2D", prev=1e-3, OR=1, pi.usr=0, n=100, rep=1,  step.save=NULL, step.load=NULL,  verbose=FALSE){
 
   sigType="D/R"
 
   if (prev >= 1 | prev <= 0) stop("Argument, prev, is out of range of (0, 1).")
-  para = c(  log(prev/(1-prev)) , log(OR))
-  dig1Code=c(4,0,1,2)
+  if (pi.usr >= 1 | pi.usr < 0) stop("Argument, pi.usr, is out of range of (0, 1).")
+
+  ## NEW ADDITION to replace old code: Added By Qing 28Jan2013
+  ## para = c( log(prev/(1-prev)), log(OR))
+  alpha = log(prev/(1-prev))
+  beta = log(OR)
+  beta.new = log(exp(alpha+beta)+pi.usr) - log (exp(alpha)+pi.usr)
+  alpha.new = log(exp(alpha)+pi.usr) - log(1-pi.usr)  
+  para = c(alpha.new, beta.new)
+  ## END of replacement
+  
+  dig1Code=c(3,2,1,0)
   ddF = NULL
   spSuphap.namePrefix=NULL
   alleleCode=1:2
@@ -52,3 +62,5 @@ function(freq,  interaction="1R and 2D", prev=1e-3, OR=1, n=100, rep=1,  step.sa
   return(trioData)
 }
 
+
+
